@@ -5,11 +5,13 @@ from trytond.model import fields
 from trytond.modules.product import price_digits
 
 
-__all__ = ['Move']
-
-
-class Move:
+class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
-    __metaclass__ = PoolMeta
     unit_landed_cost = fields.Numeric('Unit Landed Cost',
         digits=price_digits, readonly=True)
+
+    def _compute_unit_price(self, unit_price):
+        unit_price = super()._compute_unit_price(unit_price)
+        if self.unit_landed_cost:
+            unit_price += self.unit_landed_cost
+        return unit_price
